==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/offazure/kotlin/inputs/GetSqlSitesControllerPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.offazure.kotlin.inputs

import com.pulumi.azurenative.offazure.inputs.GetSqlSitesControllerPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property siteName Site name
 * @property sqlSiteName SQL site name.
 */
public data class GetSqlSitesControllerPlainArgs(
    public val resourceGroupName: String,
    public val siteName: String,
    public val sqlSiteName: String,
) : ConvertibleToJava<com.pulumi.azurenative.offazure.inputs.GetSqlSitesControllerPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.offazure.inputs.GetSqlSitesControllerPlainArgs =
        com.pulumi.azurenative.offazure.inputs.GetSqlSitesControllerPlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .siteName(siteName.let({ args0 -> args0 }))
            .sqlSiteName(sqlSiteName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSqlSitesControllerPlainArgs].
 */
@PulumiTagMarker
public class GetSqlSitesControllerPlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var siteName: String? = null

    private var sqlSiteName: String? = null

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("dhxxxwgbkueuifue")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Site name
     */
    @JvmName("aqxghiumctgkanov")
    public suspend fun siteName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.siteName = mapped
    }

    /**
     * @param value SQL site name.
     */
    @JvmName("ppvsbbkgmrhvynja")
    public suspend fun sqlSiteName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.sqlSiteName = mapped
    }

    internal fun build(): GetSqlSitesControllerPlainArgs = GetSqlSitesControllerPlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        siteName = siteName ?: throw PulumiNullFieldException("siteName"),
        sqlSiteName = sqlSiteName ?: throw PulumiNullFieldException("sqlSiteName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/offazure/kotlin/inputs/GetSqlSitesControllerPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.offazure.kotlin.inputs

import com.pulumi.azurenative.offazure.inputs.GetSqlSitesControllerPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property siteName Site name
 * @property sqlSiteName SQL site name.
 */
public data class GetSqlSitesControllerPlainArgs(
    public val resourceGroupName: String,
    public val siteName: String,
    public val sqlSiteName: String,
) : ConvertibleToJava<com.pulumi.azurenative.offazure.inputs.GetSqlSitesControllerPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.offazure.inputs.GetSqlSitesControllerPlainArgs =
        com.pulumi.azurenative.offazure.inputs.GetSqlSitesControllerPlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .siteName(siteName.let({ args0 -> args0 }))
            .sqlSiteName(sqlSiteName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSqlSitesControllerPlainArgs].
 */
@PulumiTagMarker
public class GetSqlSitesControllerPlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var siteName: String? = null

    private var sqlSiteName: String? = null

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("qasrautteabxixib")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Site name
     */
    @JvmName("yuagyonjklvrwaxt")
    public suspend fun siteName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.siteName = mapped
    }

    /**
     * @param value SQL site name.
     */
    @JvmName("dlrardlbveamahsa")
    public suspend fun sqlSiteName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.sqlSiteName = mapped
    }

    internal fun build(): GetSqlSitesControllerPlainArgs = GetSqlSitesControllerPlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        siteName = siteName ?: throw PulumiNullFieldException("siteName"),
        sqlSiteName = sqlSiteName ?: throw PulumiNullFieldException("sqlSiteName"),
    )
}
